# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connectors/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63onnectors/connector.proto\"$\n\x11\x44ispatcherRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"%\n\x12\x44ispatcherResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t2M\n\x10\x43onnectorService\x12\x39\n\nDispatcher\x12\x12.DispatcherRequest\x1a\x13.DispatcherResponse\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connectors.connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPATCHERREQUEST']._serialized_start=30
  _globals['_DISPATCHERREQUEST']._serialized_end=66
  _globals['_DISPATCHERRESPONSE']._serialized_start=68
  _globals['_DISPATCHERRESPONSE']._serialized_end=105
  _globals['_CONNECTORSERVICE']._serialized_start=107
  _globals['_CONNECTORSERVICE']._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: leads/Lead_tracker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18leads/Lead_tracker.proto\"!\n\x0eNewLeadRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\"\n\x0fNewLeadResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t2B\n\x12LeadTrackerService\x12,\n\x07NewLead\x12\x0f.NewLeadRequest\x1a\x10.NewLeadResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'leads.Lead_tracker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NEWLEADREQUEST']._serialized_start=28
  _globals['_NEWLEADREQUEST']._serialized_end=61
  _globals['_NEWLEADRESPONSE']._serialized_start=63
  _globals['_NEWLEADRESPONSE']._serialized_end=97
  _globals['_LEADTRACKERSERVICE']._serialized_start=99
  _globals['_LEADTRACKERSERVICE']._serialized_end=165
# @@protoc_insertion_point(module_scope)
